TContentType class

Wrapper type representing supported media (content) types used in OpenAPI.

Provides named constants and a factory to map raw strings to a strongly-typed value.

Constructors

TContentType.fromString(String value)
Maps a raw media type value to a supported TContentType.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw media type string value (e.g., application/json).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

applicationJson → const TContentType
application/json content type.
multipartFormData → const TContentType
multipart/form-data content type.
textJson → const TContentType
text/json content type.
textPlain → const TContentType
text/plain content type.