ModelClassGenerator constructor

ModelClassGenerator({
  1. required Components components,
  2. required String mainPath,
  3. required String globalEnumsFileString,
  4. required bool isMVVM,
})

Creates a new ModelClassGenerator.

  • components: OpenAPI components for schema lookup.
  • mainPath: Base output path for generated model files.
  • globalEnumsFileString: The full text of the global enums file (used to check if an enum already exists and import it instead).

Implementation

ModelClassGenerator({
  required this.components,
  required this.mainPath,
  required this.globalEnumsFileString,
  required this.isMVVM,
});