globalEnumsFileString property
The concatenated contents of the global enums file, used to avoid regenerating enums that already exist globally.
Implementation
final String globalEnumsFileString;
The concatenated contents of the global enums file, used to avoid regenerating enums that already exist globally.
final String globalEnumsFileString;