RemoteGenerator class

A generator responsible for creating remote data source classes.

The generated remote classes:

  • Use Dio for making HTTP requests.
  • Map requests and responses to entities and models.
  • Handle API errors consistently using throwDioException.

Constructors

RemoteGenerator({required Map<String, List<RouteInfo>> groupedRoutes, required String mainPath, required bool isMVVM})
Creates a RemoteGenerator instance with the required inputs.

Properties

groupedRoutes Map<String, List<RouteInfo>>
final
hashCode int
The hash code for this object.
no setterinherited
isMVVM bool
final
mainPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateRemoteForCategory(String category) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited