generator/network_generator/routes_generator library
Classes
- RoutesGenerator
-
A generator that creates a Dart class (
AppUrl) containing all API routes extracted from Swagger and grouped by category.
AppUrl) containing
all API routes extracted from Swagger and grouped by category.