TContentType class
Wrapper type representing supported media (content) types used in OpenAPI.
Provides named constants and a factory to map raw strings to a strongly-typed value.
Constructors
- TContentType.fromString(String value)
-
Maps a raw media type
valueto a supported TContentType.factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- applicationJson → const TContentType
-
application/jsoncontent type. - multipartFormData → const TContentType
-
multipart/form-datacontent type. - textJson → const TContentType
-
text/jsoncontent type. - textPlain → const TContentType
-
text/plaincontent type.