ModelClassGenerator constructor
ModelClassGenerator({
- required Components components,
- required String mainPath,
- required String globalEnumsFileString,
- required bool isMVVM,
Creates a new ModelClassGenerator.
components: OpenAPI components for schema lookup.mainPath: Base output path for generated model files.globalEnumsFileString: The full text of the global enums file (used to check if an enum already exists and import it instead).
Implementation
ModelClassGenerator({
required this.components,
required this.mainPath,
required this.globalEnumsFileString,
required this.isMVVM,
});