RemoteGenerator class
A generator responsible for creating remote data source classes.
The generated remote classes:
- Use
Diofor making HTTP requests. - Map requests and responses to entities and models.
- Handle API errors consistently using
throwDioException.
Constructors
-
RemoteGenerator({required Map<
String, List< groupedRoutes, required String mainPath, required bool isMVVM})RouteInfo> > - Creates a RemoteGenerator instance with the required inputs.
Properties
Methods
-
generateRemoteForCategory(
String category) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited